@@ -16,7 +16,7 @@ def read_value(text,test_number = True):
     return  val
 
 #### READ LIST
-def read_list(text,value_list=None,sep = ',',modifier_list_not=None,test_number = True):
+def read_list(text,value_list=None,sep = ',',modifier_list_not=None,test_number = True, ignore_quote = False):
 
     if not text or text.upper() == 'NONE':
         return None
@@ -42,7 +42,8 @@ def read_list(text,value_list=None,sep = ',',modifier_list_not=None,test_number
     result_list = list()
     elem_list = text.split(sep)
     for x in  elem_list:
-        elem = x.strip().strip("'\"")
+        if ignore_quote == False :
+            elem = x.strip().strip("'\"")
         if test_number :
             elem = number_test(elem)
         result_list.append(elem)
